<?php

namespace Drupal\simple_twitter_tweet\Utils;

use Drupal\node\NodeInterface;
use Drupal\Core\Config\ImmutableConfig;

/**
 * TwitterTextFromEntity class.
 *
 * Tool for get content data to tweet.
 */
class TwitterTextFromEntity {

  /**
   * Get text to tw from entity.
   */
  public static function getMessage(NodeInterface $entity) {

    $config = \Drupal::config('simple_twitter_tweet.settings');

    if ($entity->getType() !== $config->get('content')) {
      return NULL;
    }

    return self::getTextValue($entity, $config);

  }

  /**
   * Get text field value from entity.
   */
  private static function getTextValue(
      NodeInterface $entity,
      ImmutableConfig $config
    ) {
    $status = '';

    $text_field = $entity->{$config->get('body')};
    $field_type = $text_field->getFieldDefinition()->getType();

    if (in_array(
        $field_type,
        ['string', 'text', 'text_with_summary', 'string_long']
      )) {
      $status = $text_field->value;
      if (
        !empty($config->get('body_use_summary'))
        && !empty($text_field->summary)
      ) {
        $status = $text_field->summary;
      }
    }

    if ($config->get('body') === 'title') {
      $status = $entity->getTitle();
    }

    if ($config->get('body_concat_url')) {
      $link = self::getEntityLink($entity);
      $status = self::calculateCharNumberTw($status, $link);
    }

    return strip_tags($status);
  }

  /**
   * Retorna texto para nuevo status que no supera los max de caracteres.
   *
   * @param string $text
   *   El texto que se obtuvo de la entidad.
   * @param string $link
   *   El enlace a la entidad.
   *
   * @return string
   *   texto para la actualizacion de estado
   *   que no supera el nro de caracteres permitiido
   *   URL: todas las URL están envueltas en enlaces t.co.
   *   Esto significa que la longitud de una URL está
   *   definida por el parámetro transformURLLength
   *   en el archivo de configuración de texto de Twitter.
   *   La longitud actual de una URL en un Tweet es de 23 caracteres,
   *   incluso si la longitud de la URL normalmente fuera más corta.
   */
  private static function calculateCharNumberTw($text, $link) {
    if (empty($text) && empty($link)) {
      return FALSE;
    }

    // Maximo de caracteres en un tweet.
    $tweet_max = 280;
    // Los caracteres que se pierden por incluir un link en el tweet + espacio.
    $https_len = 24;
    // Clear.
    $text = strip_tags($text, NULL);

    if (empty($link)) {
      // Tweet solo texto.
      // Recorta de ser necesario.
      return substr($text, 0, $tweet_max);
    }
    elseif (empty($text)) {
      return $link;
    }

    return substr($text, 0, $tweet_max - $https_len) . ' ' . $link;
  }

  /**
   * Get link of entity method.
   */
  private static function getEntityLink($entity) {
    return $entity->toUrl()->setAbsolute(TRUE)->toString();
  }

}
