<?php

namespace Drupal\simple_twitter_tweet\Utils;

use Abraham\TwitterOAuth\TwitterOAuth;

/**
 * TwitterWrapper class.
 *
 * A tool class for tweet text.
 */
class TwitterWrapper {

  /**
   * Tweet method.
   */
  public static function tweet(string $text) {

    $twitter = new TwitterOAuth(
      \Drupal::state()
        ->get('simple_twitter_tweet.twitter_consumer_key', ''),
      \Drupal::state()
        ->get('simple_twitter_tweet.twitter_consumer_secret', ''),
      \Drupal::state()
        ->get('simple_twitter_tweet.twitter_access_token', ''),
      \Drupal::state()
        ->get('simple_twitter_tweet.twitter_access_token_secret', '')
    );

    $twitter->setTimeouts(25, 15);

    try {
      $statues = $twitter->post("statuses/update", ["status" => $text]);

      if ($twitter->getLastHttpCode() == 200) {
        // Tweet posted successfully.
        \Drupal::logger('simple_twitter_tweet')
          ->notice('New tweet created');
        return $statues->id_str;
      }
      elseif (isset($statues->errors)) {
        // Handle error case.
        \Drupal::logger('simple_twitter_tweet')
          ->error('an error has occurred: ' . $statues->errors[0]->message);
      }
      else {
        \Drupal::logger('simple_twitter_tweet')
          ->error('an error has occurred');
      }
    }
    catch (\Exception $e) {
      \Drupal::logger('simple_twitter_tweet')
        ->error($e->getMessage());
      return FALSE;
    }

    return FALSE;
  }

  /**
   * Test twitter api connection.
   */
  public static function testApiAccess(
      $consumer_key,
      $consumer_secret,
      $token,
      $token_secret
    ) {

    $tw = new TwitterOAuth(
      $consumer_key,
      $consumer_secret,
      $token,
      $token_secret
    );
    $tw->setTimeouts(10, 15);
    $tw->setApiVersion('2');

    $uid = explode('-', $token)[0];
    $content = $tw->get('users', ['ids' => $uid]);
    if (isset($content->errors)) {
      foreach ($content->errors as $error) {

        return t(
            'Account verification failed, Twitter returned the following Error
             code @error_code: "@error_msg".',
            ['@error_code' => $error->code, '@error_msg' => $error->message]
        );
      }
    }
    elseif (isset($content->data)) {
      foreach ($content->data as $data) {
        return t('Ok, @user.', ['@user' => $data->username]);
      }

    }
    else {
      return $content->title ?? 'Ocurrio un problema';
    }
  }

}
